__all__ = ('IMAGE_CHOICES', 'IMAGE_CHOICES_WITH_EMPTY_OPTION')

from dash.contrib.plugins.url.conf import get_setting

IMAGE_CHOICES = get_setting('IMAGE_CHOICES')
IMAGE_CHOICES_WITH_EMPTY_OPTION = get_setting('IMAGE_CHOICES_WITH_EMPTY_OPTION')



__all__ = ('RESTRICT_PLUGIN_ACCESS', 'PLUGINS_MODULE_NAME', 'LAYOUTS_MODULE_NAME', 'ACTIVE_LAYOUT', \
           'LAYOUT_CELL_UNITS', 'DEFAULT_WORKSPACE_NAME', 'DEFAULT_PLACEHOLDER_VIEW_TEMPLATE_NAME', \
           'DEFAULT_PLACEHOLDER_EDIT_TEMPLATE_NAME', 'DISPLAY_LOGOUT_LINK', 'DEBUG')

gettext = lambda s: s

# If set to True, plugins would be only accessible by the white-listed user(s) or group(s). If set to False, all
# users have the same access rights to all plugins.
RESTRICT_PLUGIN_ACCESS = True

# Name of the module in which the dash plugins are registered.
PLUGINS_MODULE_NAME = 'dash_plugins'

# Name of the module in which the dash layouts are registered.
LAYOUTS_MODULE_NAME = 'dash_layouts'

# UID of the active layout.
ACTIVE_LAYOUT = 'android'

# Allowed layout cell units.
LAYOUT_CELL_UNITS = ('em', 'px', 'pt', '%')

# Name of the default dashboard workspace (no workspace).
DEFAULT_WORKSPACE_NAME = 'Default'

DEFAULT_PLACEHOLDER_VIEW_TEMPLATE_NAME = 'dash/layouts/base_placeholder_view.html'
DEFAULT_PLACEHOLDER_EDIT_TEMPLATE_NAME = 'dash/layouts/base_placeholder_edit.html'

# If set to True, the logout link is shown in the menu.
DISPLAY_LOGOUT_LINK = True

DEBUG = False



__all__ = ('VideoAndroidMainWidget', 'BigVideoAndroidMainWidget', 'HugeVideoAndroidMainWidget', \
           'GiganticVideoAndroidMainWidget', 'VideoWindows8MainWidget', 'VideoWindows8SidebarWidget')

from django.template.loader import render_to_string

from dash.base import BaseDashboardPluginWidget

# **********************************************************************
# ****************** Android widgets for Video plugin ******************
# **********************************************************************

class VideoAndroidMainWidget(BaseDashboardPluginWidget):
    """
    Video plugin widget for Android layout (placeholder `main`).
    """
    layout_uid = 'android'
    placeholder_uid = 'main'
    plugin_uid = 'video'
    cols = 2
    rows = 2
    media_css = (
        'css/dash_plugin_video.css',
    )

    def render(self, request=None):
        context = {'plugin': self.plugin}
        return render_to_string('video/render_main.html', context)


# **********************************************************************
# ****************** Android widgets for Big video plugin **************
# **********************************************************************

class BigVideoAndroidMainWidget(VideoAndroidMainWidget):
    """
    Big video plugin widget for Android layout (placeholder `main`).
    """
    plugin_uid = 'big_video'
    cols = 3
    rows = 3

# **********************************************************************
# ****************** Android widgets for Huge video plugin *************
# **********************************************************************

class HugeVideoAndroidMainWidget(VideoAndroidMainWidget):
    """
    Huge video plugin widget for Android layout (placeholder `main`).
    """
    plugin_uid = 'huge_video'
    cols = 4
    rows = 4

# **********************************************************************
# ****************** Android widgets for Gigantic video plugin *********
# **********************************************************************

class GiganticVideoAndroidMainWidget(VideoAndroidMainWidget):
    """
    Gigantic video plugin widget for Android layout (placeholder `main`).
    """
    plugin_uid = 'gigantic_video'
    cols = 5
    rows = 5

# **********************************************************************
# ****************** Windows 8 widgets for Video plugin ****************
# **********************************************************************

class VideoWindows8MainWidget(BaseDashboardPluginWidget):
    """
    Video plugin widget for Windows 8 layout (placeholder `main`).
    """
    layout_uid = 'windows8'
    placeholder_uid = 'main'
    plugin_uid = 'video'
    cols = 2
    rows = 2
    media_css = (
        'css/dash_plugin_video.css',
    )

    def render(self, request=None):
        context = {'plugin': self.plugin}
        return render_to_string('video/render_main.html', context)


class VideoWindows8SidebarWidget(VideoWindows8MainWidget):
    """
    Video plugin widget for Windows 8 layout (placeholder `sidebar`).
    """
    placeholder_uid = 'sidebar'



__all__ = ('ReadRSSFeedForm',)

from django import forms
from django.utils.translation import ugettext_lazy as _

from dash.base import DashboardPluginFormBase
from dash.widgets import BooleanRadioSelect
from dash.contrib.plugins.rss_feed.defaults import DEFAULT_MAX_FEED_ITEMS, DEFAULT_TRUNCATE_AFTER, DEFAULT_CACHE_FOR
from dash.contrib.plugins.rss_feed.defaults import DEFAULT_SHOW_TITLE

class ReadRSSFeedForm(forms.Form, DashboardPluginFormBase):
    """
    Form for main ``ReadRSSFeedPlugin``.
    """
    plugin_data_fields = [
        ("feed_url", ""),
        ("custom_feed_title", ""),
        ("show_feed_title", DEFAULT_SHOW_TITLE),
        ("max_items", DEFAULT_MAX_FEED_ITEMS),
        ("truncate_after", DEFAULT_TRUNCATE_AFTER),
        ("cache_for", DEFAULT_CACHE_FOR)
    ]
    feed_url = forms.URLField(label=_("Feed URL"), required=True)
    custom_feed_title = forms.CharField(label=_("Custom feed title"), required=False)
    show_feed_title = forms.BooleanField(label=_("Show feed title?"), required=False, initial=DEFAULT_SHOW_TITLE, \
                                         widget=BooleanRadioSelect)
    max_items = forms.IntegerField(label=_("Max feed items to show"), required=True, initial=DEFAULT_MAX_FEED_ITEMS)
    truncate_after = forms.IntegerField(label=_("Truncate after"), required=False, initial=DEFAULT_TRUNCATE_AFTER)
    cache_for = forms.IntegerField(label=_("Cache for"), required=True, initial=DEFAULT_CACHE_FOR)



__all__ = ('URLForm',)

from django import forms
from django.utils.translation import ugettext_lazy as _

from dash.base import DashboardPluginFormBase
from dash.widgets import BooleanRadioSelect
from dash.contrib.plugins.url.settings import IMAGE_CHOICES_WITH_EMPTY_OPTION

class URLForm(forms.Form, DashboardPluginFormBase):
    """
    URL form for `URLPlugin` plugin.
    """
    class Media:
        css = {
            'all': ('css/dash_plugin_url_form.css',)
        }
        js = ('js/dash_plugin_url_form.js',)

    plugin_data_fields = [
        ("title", ""),
        ("url", ""),
        ("external", False),
        ("image", "")
    ]

    title = forms.CharField(label=_("Title"), required=True)
    url = forms.URLField(label=_("URL"), required=True)
    external = forms.BooleanField(label=_("External?"), required=False, initial=False, widget=BooleanRadioSelect)
    image = forms.ChoiceField(label=_("Image"), required=False, choices=IMAGE_CHOICES_WITH_EMPTY_OPTION)

    def __init__(self, *args, **kwargs):
        super(URLForm, self).__init__(*args, **kwargs)

        if 'class' in self.fields['image'].widget.attrs:
            self.fields['image'].widget.attrs['class'] += ' image-picker'
        else:
            self.fields['image'].widget.attrs['class'] = 'image-picker'

        


__all__ = ('ReadRSSFeedPlugin', 'BigReadRSSFeedPlugin')

from django.utils.translation import ugettext_lazy as _

from dash.base import BaseDashboardPlugin, plugin_registry, plugin_widget_registry
from dash.contrib.plugins.rss_feed.forms import ReadRSSFeedForm
from dash.contrib.plugins.rss_feed.dash_widgets import ReadRSSFeedAndroidMainWidget, ReadRSSFeedWindows8MainWidget
from dash.contrib.plugins.rss_feed.dash_widgets import BigReadRSSFeedAndroidMainWidget

# ***************************************************************************
# ******************************* Read RSS feed plugin **********************
# ***************************************************************************

class ReadRSSFeedPlugin(BaseDashboardPlugin):
    """
    Read RSS feed into HTML plugin.
    """
    uid = 'read_rss_feed'
    name = _("Read RSS feed")
    form = ReadRSSFeedForm
    group = _("Internet")

plugin_registry.register(ReadRSSFeedPlugin)

# ***************************************************************************
# ******************************* Read RSS feed plugin **********************
# ***************************************************************************

class BigReadRSSFeedPlugin(ReadRSSFeedPlugin):
    """
    Big read RSS feed into HTML plugin.
    """
    uid = 'big_read_rss_feed'
    name = _("Read RSS feed")

plugin_registry.register(BigReadRSSFeedPlugin)

# *************************************************************************
# ****************** Registering the widgets ******************************
# *************************************************************************

# Registering the Android widgets for Read RSS feed plugin plugin.
plugin_widget_registry.register(ReadRSSFeedAndroidMainWidget)
plugin_widget_registry.register(BigReadRSSFeedAndroidMainWidget)

# Registering the Windows8 widgets for Dummy plugin.
plugin_widget_registry.register(ReadRSSFeedWindows8MainWidget)



__all__ = ('DummyPlugin',)

from django.utils.translation import ugettext_lazy as _

from dash.base import BaseDashboardPlugin, plugin_registry, plugin_widget_registry
from dash.contrib.plugins.dummy.forms import DummyForm, DummyShortcutsForm

from dash.contrib.plugins.dummy.dash_widgets import DummyAndroidMainWidget, DummyAndroidShortcutWidget
from dash.contrib.plugins.dummy.dash_widgets import DummyWindows8MainWidget, DummyWindows8SidebarWidget
from dash.contrib.plugins.dummy.dash_widgets import LargeDummyAndroidMainWidget, LargeDummyPortraitAndroidMainWidget
from dash.contrib.plugins.dummy.dash_widgets import LargeDummyPortraitAndroidShortcutWidget
from dash.contrib.plugins.dummy.dash_widgets import BigDummyAndroidMainWidget

# ***************************************************************************
# ******************************* Dummy plugin ******************************
# ***************************************************************************

class DummyPlugin(BaseDashboardPlugin):
    """
    Dummy dashboard plugin.
    """
    uid = 'dummy'
    name = _("Dummy")
    form = DummyForm
    group = _("Dummy")

    def get_form(self):
        if 'sidebar' == self.placeholder:
            return DummyShortcutsForm
        else:
            return DummyForm

    def post_processor(self):
        """
        If no text available, use dummy.
        """
        if not self.data.text:
            self.data.text = 'Dummy content'


plugin_registry.register(DummyPlugin)

# ********************************************************************************
# ******************************* Large dummy plugin *****************************
# ********************************************************************************

class LargeDummyPlugin(DummyPlugin):
    """
    Large dummy dashboard plugin.
    """
    uid = 'large_dummy'
    name = _("Dummy")
    group = _("Dummy")


plugin_registry.register(LargeDummyPlugin)

# ****************************************************************************************
# ******************************* Large dummy portrait plugin ****************************
# ****************************************************************************************

class LargeDummyPortraitPlugin(DummyPlugin):
    """
    Large dummy portrait dashboard plugin.
    """
    uid = 'large_dummy_portrait'
    name = _("Dummy")
    group = _("Dummy")


plugin_registry.register(LargeDummyPortraitPlugin)

# ********************************************************************************
# ******************************* Big dummy plugin *******************************
# ********************************************************************************

class BigDummyPlugin(DummyPlugin):
    """
    Big dummy dashboard plugin.
    """
    uid = 'big_dummy'
    name = _("Dummy")
    group = _("Dummy")


plugin_registry.register(BigDummyPlugin)

# ********************************************************************************
# ******************************* Registering the widgets ************************
# ********************************************************************************

# Registering the Android widgets for Dummy plugin.
plugin_widget_registry.register(DummyAndroidMainWidget)
plugin_widget_registry.register(DummyAndroidShortcutWidget)

# Registering the Windows8 widgets for Dummy plugin.
plugin_widget_registry.register(DummyWindows8MainWidget)
plugin_widget_registry.register(DummyWindows8SidebarWidget)

# Registering the Android widgets for Large dummy plugin.
plugin_widget_registry.register(LargeDummyAndroidMainWidget)

# Registering the Android widgets for LargeDummy plugin.
plugin_widget_registry.register(LargeDummyPortraitAndroidMainWidget)
plugin_widget_registry.register(LargeDummyPortraitAndroidShortcutWidget)

# Registering the Android widgets for Big dummy plugin.
plugin_widget_registry.register(BigDummyAndroidMainWidget)



__all__ = ('SATISFY_ANY', 'SATISFY_ALL', 'DEFAULT_SATISFY', 'permissions_required', 'all_permissions_required', \
           'any_permission_required', 'edit_dashboard_permission_required')

SATISFY_ANY = 'any'
SATISFY_ALL = 'all'
DEFAULT_SATISFY = SATISFY_ALL

from django.core.exceptions import PermissionDenied
from django.contrib.auth.decorators import user_passes_test

def permissions_required(perms, satisfy=DEFAULT_SATISFY, login_url=None, raise_exception=False):
    """
    Checks for the permissions given based on the strategy chosen.

    :param iterable perms:
    :param str satisfy: Allowed values are "all" and "any".
    :param str login_url:
    :param bool raise_exception: If set to True, the ``PermissionDenied`` exception is raised on failures.
    :return bool:

    :example:
    >>> @login_required
    >>> @permissions_required(satisfy='any', perms=[
    >>>     'dash.add_dashboardentry', 'dash.change_dashboardentry', 'dash.delete_dashboardentry',
    >>>     'dash.add_dashboardworkspace', 'dash.change_dashboardworkspace', 'dash.delete_dashboardworkspace',
    >>>     'dash.add_dashboardsettings', 'dash.change_dashboardsettings', 'dash.delete_dashboardsettings',
    >>> ])
    >>> def edit_dashboard(request):
    >>>     # your code
    """
    assert satisfy in (SATISFY_ANY, SATISFY_ALL)

    if SATISFY_ALL == satisfy:
        # ``SATISFY_ALL`` case
        def check_perms(user):
            # First check if the user has the permission (even anon users)
            if user.has_perms(perms):
                return True
            # In case the 403 handler should be called raise the exception
            if raise_exception:
                raise PermissionDenied
            # As the last resort, show the login form
            return False
    else:
        # ``SATISFY_ANY`` case
        def check_perms(user):
            # First check if the user has the permission (even anon users)
            for perm in perms:
                if user.has_perm(perm):
                    return True

            # In case the 403 handler should be called raise the exception
            if raise_exception:
                raise PermissionDenied
            # As the last resort, show the login form
            return False

    return user_passes_test(check_perms, login_url=login_url)

def all_permissions_required(perms, login_url=None, raise_exception=False):
    """
    :example:
    >>> @login_required
    >>> @all_permissions_required([
    >>>     'dash.add_dashboardentry', 'dash.change_dashboardentry', 'dash.delete_dashboardentry',
    >>>     'dash.add_dashboardworkspace', 'dash.change_dashboardworkspace', 'dash.delete_dashboardworkspace',
    >>>     'dash.add_dashboardsettings', 'dash.change_dashboardsettings', 'dash.delete_dashboardsettings',
    >>> ])
    >>> def edit_dashboard(request):
    >>>     # your code
    """
    return permissions_required(perms, satisfy=SATISFY_ALL, login_url=login_url, raise_exception=raise_exception)

def any_permission_required(perms, login_url=None, raise_exception=False):
    """
    :example:
    >>> @login_required
    >>> @any_permission_required([
    >>>     'dash.add_dashboardentry', 'dash.change_dashboardentry', 'dash.delete_dashboardentry',
    >>>     'dash.add_dashboardworkspace', 'dash.change_dashboardworkspace', 'dash.delete_dashboardworkspace',
    >>>     'dash.add_dashboardsettings', 'dash.change_dashboardsettings', 'dash.delete_dashboardsettings',
    >>> ])
    >>> def edit_dashboard(request):
    >>>     # your code
    """
    return permissions_required(perms, satisfy=SATISFY_ANY, login_url=login_url, raise_exception=raise_exception)

def edit_dashboard_permission_required(login_url=None, raise_exception=False):
    """
    Checks if user has permissions to edit dashboard. Simply, check is successfull if any of the following
    permission checks are satisfied:
    
        - Can add dashboard entry
        - Can change dashboard entry
        - Can delete dashboard entry
        - Can add dashboard workspace
        - Can change dashboard workspace
        - Can delete dashboard workspace
        - Can add dashboard settings
        - Can change dashboard settings
        - Can delete dashboard settings

    :example:
    >>> @login_required
    >>> @edit_dashboard_permission_required() # Do not forget the brackets!
    >>> def edit_dashboard(request):
    >>>     # your code
    """
    return permissions_required(
        perms = [
            'dash.add_dashboardentry', 'dash.change_dashboardentry', 'dash.delete_dashboardentry',
            'dash.add_dashboardworkspace', 'dash.change_dashboardworkspace', 'dash.delete_dashboardworkspace',
            'dash.add_dashboardsettings', 'dash.change_dashboardsettings', 'dash.delete_dashboardsettings',
        ],
        satisfy = SATISFY_ANY,
        login_url = login_url,
        raise_exception = raise_exception
        )



__all__ = ('DummyAndroidMainWidget', 'DummyAndroidShortcutWidget', 'DummyWindows8MainWidget', \
           'DummyWindows8SidebarWidget', 'LargeDummyAndroidMainWidget', \
           'LargeDummyPortraitAndroidMainWidget', 'LargeDummyPortraitAndroidShortcutWidget', \
           'BigDummyAndroidMainWidget')

from django.template.loader import render_to_string

from dash.base import BaseDashboardPluginWidget

# ************************************************************************
# ****************** Android widgets for Dummy plugin ********************
# ************************************************************************

class DummyAndroidMainWidget(BaseDashboardPluginWidget):
    """
    Dummy plugin widget for Android layout (placeholder `main`).
    """
    layout_uid = 'android'
    placeholder_uid = 'main'
    plugin_uid = 'dummy'
    media_js = [
        #'js/dash_plugin_dummy.js',
    ]
    media_css = [
        #'css/dash_plugin_dummy.css',
    ]

    def render(self, request=None):
        context = {'plugin': self.plugin}
        return render_to_string('dummy/render_main.html', context)


class DummyAndroidShortcutWidget(DummyAndroidMainWidget):
    """
    Dummy plugin widget for Android layout (placeholder `shortcuts`).
    """
    placeholder_uid = 'shortcuts'

    def render(self, request=None):
        context = {'plugin': self.plugin}
        return render_to_string('dummy/render_shortcuts.html', context)

# ************************************************************************
# ****************** Windows8 widgets for Dummy plugin *******************
# ************************************************************************

class DummyWindows8MainWidget(DummyAndroidMainWidget):
    """
    Dummy plugin widget for Windows8 (placeholder `main`).
    """
    layout_uid = 'windows8'


class DummyWindows8SidebarWidget(DummyWindows8MainWidget):
    """
    Dummy plugin widget for Windows8 (placeholder `sidebar`).
    """
    layout_uid = 'windows8'
    placeholder_uid = 'sidebar'

# ************************************************************************
# ****************** Android widgets for Large dummy plugin **************
# ************************************************************************

class LargeDummyAndroidMainWidget(DummyAndroidMainWidget):
    """
    Large dummy plugin widget for Android (placeholder `main`).
    """
    plugin_uid = 'large_dummy'
    cols = 2
    rows = 1

# ************************************************************************
# ****************** Android widgets for Large dummy plugin **************
# ************************************************************************

class LargeDummyPortraitAndroidMainWidget(DummyAndroidMainWidget):
    """
    Large dummy portrait plugin widget for Android (placeholder `main`).
    """
    plugin_uid = 'large_dummy_portrait'
    cols = 1
    rows = 2


class LargeDummyPortraitAndroidShortcutWidget(DummyAndroidShortcutWidget):
    """
    Large dummy portrait plugin widget for Android (placeholder `shortcuts`).
    """
    plugin_uid = 'large_dummy_portrait'
    cols = 1
    rows = 2

# ************************************************************************
# ****************** Android widgets for Big dummy plugin ****************
# ************************************************************************

class BigDummyAndroidMainWidget(DummyAndroidMainWidget):
    """
    Big dummy portrait plugin widget for Android (placeholder `main`).
    """
    plugin_uid = 'big_dummy'
    cols = 3
    rows = 3



__all__ = ('URLAndroidMainWidget', 'URLAndroidShortcutWidget', 'URLWindows8MainWidget', 'URLWindows8SidebarWidget')

from django.template.loader import render_to_string

from dash.base import BaseDashboardPluginWidget

# **********************************************************************
# ****************** Android widgets for URL plugin ********************
# **********************************************************************

class URLAndroidMainWidget(BaseDashboardPluginWidget):
    """
    URL plugin widget for Android layout (placeholder `main`).
    """
    layout_uid = 'android'
    placeholder_uid = 'main'
    plugin_uid = 'url'
    cols = 1
    rows = 1
    media_css = (
        'css/dash_plugin_url_android.css',
    )

    def render(self, request=None):
        context = {'plugin': self.plugin}
        return render_to_string('url/render_main.html', context)


class URLAndroidShortcutWidget(URLAndroidMainWidget):
    """
    URL plugin widget for Android layout (placeholder `shortcuts`).
    """
    placeholder_uid = 'shortcuts'
    cols = 1
    rows = 1

    def render(self, request=None):
        context = {'plugin': self.plugin}
        return render_to_string('url/render_shortcuts.html', context)


# **********************************************************************
# ****************** Windows 8 widgets for URL plugin ******************
# **********************************************************************

class URLWindows8MainWidget(BaseDashboardPluginWidget):
    """
    URL plugin widget for Windows 8 layout (placeholder `main`).
    """
    layout_uid = 'windows8'
    placeholder_uid = 'main'
    plugin_uid = 'url'
    cols = 1
    rows = 1
    media_css = (
        'css/dash_plugin_url_windows8.css',
    )

    def render(self, request=None):
        context = {'plugin': self.plugin}
        return render_to_string('url/render_main.html', context)


class URLWindows8SidebarWidget(URLWindows8MainWidget):
    """
    URL plugin widget for Windows 8 layout (placeholder `sidebar`).
    """
    placeholder_uid = 'sidebar'



__all__ = ('NewsAndroidMainWidget', 'HugeNewsAndroidMainWidget')

from django.template.loader import render_to_string

from dash.base import BaseDashboardPluginWidget
from dash.contrib.plugins.news.constants import PAGE_URL_PARAM, NUM_POSTS_URL_PARAM

# ************************************************************************
# ****************** Android widgets for Read RSS feed plugin ************
# ************************************************************************
class NewsAndroidMainWidget(BaseDashboardPluginWidget):
    """
    News plugin widget for Android layout (placeholder `main`).
    """
    layout_uid = 'android'
    placeholder_uid = 'main'
    plugin_uid = 'news'
    cols = 2
    rows = 5

    media_js = [
        'js/dash_plugin_news.js',
    ]
    media_css = [
        'css/dash_plugin_news.css',
    ]

    def render(self, request=None):
        context = {'plugin': self.plugin,}
        return render_to_string('news/render_main.html', context)


# ************************************************************************
# ****************** Android widgets for Read RSS feed plugin ************
# ************************************************************************
class HugeNewsAndroidMainWidget(NewsAndroidMainWidget):
    """
    Huge news plugin widget for Android layout (placeholder `main`).
    """
    plugin_uid = 'huge_news'
    cols = 4
    rows = 5

    media_js = [
        'js/dash_plugin_huge_news.js',
    ]
    media_css = [
        'css/dash_plugin_news.css',
    ]

    def render(self, request=None):
        context = {
            'plugin': self.plugin,
            'PAGE_URL_PARAM': PAGE_URL_PARAM,
            'NUM_POSTS_URL_PARAM': NUM_POSTS_URL_PARAM
            }
        return render_to_string('news/render_huge_main.html', context)



__all__ = ('MemoAndroidMainWidget', 'MemoAndroidShortcutWidget', 'BigMemoAndroidMainWidget', \
           'BigMemoWindows8MainWidget', 'HugeMemoAndroidMainWidget', 'TinyMCEMemoAndroidMainWidget', \
           'BigTinyMCEMemoAndroidMainWidget', 'MemoWindows8MainWidget', 'MemoWindows8SidebarWidget', \
           'BigMemoWindows8MainWidget', 'BigMemoWindows8SidebarWidget')

from django.template.loader import render_to_string

from dash.base import BaseDashboardPluginWidget

# ***********************************************************************
# ****************** Android widgets for Memo plugin ********************
# ***********************************************************************

class MemoAndroidMainWidget(BaseDashboardPluginWidget):
    """
    Memo plugin widget for Android layout (placeholder `main`).
    """
    layout_uid = 'android'
    placeholder_uid = 'main'
    plugin_uid = 'memo'
    cols = 2
    rows = 2

    def render(self, request=None):
        context = {'plugin': self.plugin}
        return render_to_string('memo/render_main.html', context)


class MemoAndroidShortcutWidget(MemoAndroidMainWidget):
    """
    Memo plugin widget for Android layout (placeholder `shortcuts`).
    """
    placeholder_uid = 'shortcuts'
    cols = 1
    rows = 1

    def render(self, request=None):
        context = {'plugin': self.plugin}
        return render_to_string('memo/render_shortcuts.html', context)

# ***************************************************************************
# ****************** Android widgets for Big memo plugin ********************
# ***************************************************************************

class BigMemoAndroidMainWidget(MemoAndroidMainWidget):
    """
    Big memo plugin widget for Android layout (placeholder `main`).
    """
    plugin_uid = 'big_memo'
    cols = 3
    rows = 3

# ***************************************************************************
# ****************** Windows8 widgets for Big memo plugin *******************
# ***************************************************************************

class BigMemoWindows8MainWidget(BigMemoAndroidMainWidget):
    """
    Big memo plugin widget for Windows8 layout (placeholder `main`).
    """
    layout_uid = 'windows8'

# ***************************************************************************
# ****************** Android widgets for Huge memo plugin *******************
# ***************************************************************************

class HugeMemoAndroidMainWidget(MemoAndroidMainWidget):
    """
    Huge memo plugin widget for Android layout (placeholder `main`).
    """
    plugin_uid = 'huge_memo'
    cols = 4
    rows = 5


# ***********************************************************************
# ****************** Android widgets for TinyMCEMemo plugin *************
# ***********************************************************************

class TinyMCEMemoAndroidMainWidget(BaseDashboardPluginWidget):
    """
    TinyMCE memo plugin widget for Android layout (placeholder `main`).
    """
    layout_uid = 'android'
    placeholder_uid = 'main'
    plugin_uid = 'tinymce_memo'
    cols = 2
    rows = 2

    def render(self, request=None):
        context = {'plugin': self.plugin}
        return render_to_string('tinymce/render_main.html', context)

# ***************************************************************************
# ****************** Android widgets for Big TinyMCE memo plugin ************
# ***************************************************************************

class BigTinyMCEMemoAndroidMainWidget(TinyMCEMemoAndroidMainWidget):
    """
    Big memo plugin widget for Android layout (placeholder `main`).
    """
    plugin_uid = 'big_tinymce_memo'
    cols = 3
    rows = 3


# ***********************************************************************
# ****************** Windows8 widgets for Memo plugin *******************
# ***********************************************************************

class MemoWindows8MainWidget(BaseDashboardPluginWidget):
    """
    Memo plugin widget for Windows 8 layout (placeholder `main`).
    """
    layout_uid = 'windows8'
    placeholder_uid = 'main'
    plugin_uid = 'memo'
    cols = 2
    rows = 2

    def render(self, request=None):
        context = {'plugin': self.plugin}
        return render_to_string('memo/render_main.html', context)


class MemoWindows8SidebarWidget(MemoWindows8MainWidget):
    """
    Memo plugin widget for Windows8 layout (placeholder `sidebar`).
    """
    placeholder_uid = 'sidebar'
    cols = 1
    rows = 1

    def render(self, request=None):
        context = {'plugin': self.plugin}
        return render_to_string('memo/render_shortcuts.html', context)


# ***************************************************************************
# ****************** Windows 8 widgets for Big memo plugin ******************
# ***************************************************************************

class BigMemoWindows8MainWidget(MemoAndroidMainWidget):
    """
    Big memo plugin widget for Windows 8 layout (placeholder `main`).
    """
    layout_uid = 'windows8'
    plugin_uid = 'big_memo'
    cols = 3
    rows = 3


class BigMemoWindows8SidebarWidget(BigMemoWindows8MainWidget):
    """
    Big memo plugin widget for Windows 8 layout (placeholder `sidebar`).
    """
    layout_uid = 'windows8'
    placeholder_uid = 'sidebar'
    plugin_uid = 'big_memo'
    cols = 2
    rows = 2




from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from dash.models import DashboardWorkspace, DashboardEntry, DashboardPlugin, DashboardSettings

class DashboardWorkspaceAdmin(admin.ModelAdmin):
    """
    Dashboard workspace admin.
    """
    list_display = ('name', 'slug', 'layout_uid', 'position', 'user', 'is_public')
    list_editable = ('position',)
    list_filter = ('layout_uid', 'is_public')
    readonly_fields = ('slug',)
    fieldsets = (
        (None, {
            'fields': ('name', 'position', 'is_public')
        }),
        (_("User"), {
            'fields': ('user',)
        }),
        (_('Additional'), {
            'classes': ('collapse',),
            'fields': ('slug',)
        }),
    )

    class Meta:
        app_label = _('Dashboard workspace')


admin.site.register(DashboardWorkspace, DashboardWorkspaceAdmin)

class DashboardEntryAdmin(admin.ModelAdmin):
    """
    Dashboard entry admin.
    """
    list_display = ('plugin_uid', 'plugin_uid_code', 'plugin_data', 'layout_uid', 'placeholder_uid', 'position',
                    'workspace', 'user')
    list_filter = ('user', 'workspace', 'layout_uid', 'placeholder_uid', 'plugin_uid')
    list_editable = ('position',)
    readonly_fields = ('plugin_uid_code',)
    fieldsets = (
        (None, {
            'fields': ('plugin_uid', 'plugin_data', 'layout_uid', 'placeholder_uid', 'position', 'workspace')
        }),
        (_("User"), {
            'fields': ('user',)
        }),
    )

    class Meta:
        app_label = _('Dashboard entry')

    def queryset(self, request):
        queryset = super(DashboardEntryAdmin, self).queryset(request)
        queryset = queryset.select_related('workspace', 'user')
        return queryset


admin.site.register(DashboardEntry, DashboardEntryAdmin)

class DashboardPluginAdmin(admin.ModelAdmin):
    """
    Dashboard plugin admin.
    """
    list_display = ('plugin_uid_admin', 'users_list', 'groups_list')
    readonly_fields = ('plugin_uid', 'plugin_uid_admin')
    fieldsets = (
        (None, {
            'fields': ('plugin_uid', 'users', 'groups')
        }),
    )
    filter_horizontal = ('users', 'groups',)

    class Meta:
        app_label = _('Dashboard plugin')

    def queryset(self, request):
        queryset = super(DashboardPluginAdmin, self).queryset(request)
        queryset = queryset.prefetch_related('users', 'groups')
        return queryset


admin.site.register(DashboardPlugin, DashboardPluginAdmin)

class DashboardSettingsAdmin(admin.ModelAdmin):
    """
    Dashboard plugin admin.
    """
    list_display = ('title', 'user', 'layout_uid', 'is_public')
    #readonly_fields = ('plugin_uid',)
    fieldsets = (
        (None, {
            'fields': ('title', 'user', 'layout_uid', 'is_public')
        }),
    )

    class Meta:
        app_label = _('Dashboard settings')

    def queryset(self, request):
        queryset = super(DashboardSettingsAdmin, self).queryset(request)
        queryset = queryset.select_related('user')
        return queryset


admin.site.register(DashboardSettings, DashboardSettingsAdmin)



__all__ = ('VideoPlugin', 'BigVideoPlugin', 'HugeVideoPlugin', 'GiganticVideoPlugin')

from django.utils.translation import ugettext_lazy as _

from vishap import render_video

from dash.base import BaseDashboardPlugin, plugin_registry, plugin_widget_registry
from dash.contrib.plugins.video.forms import VideoForm
from dash.contrib.plugins.video.dash_widgets import VideoAndroidMainWidget, BigVideoAndroidMainWidget
from dash.contrib.plugins.video.dash_widgets import HugeVideoAndroidMainWidget, GiganticVideoAndroidMainWidget
from dash.contrib.plugins.video.dash_widgets import VideoWindows8MainWidget, VideoWindows8SidebarWidget

# *************************************************************************
# ******************************* Video plugin ****************************
# *************************************************************************

class VideoPlugin(BaseDashboardPlugin):
    """
    Video dashboard plugin.
    """
    uid = 'video'
    name = _("Video")
    group = _("Internet")
    form = VideoForm

    @property
    def html_class(self):
        """
        If plugin has an image, we add a class `iconic` to it.
        """
        html_class = super(VideoPlugin, self).html_class
        html_class += ' video'
        return html_class

    def post_processor(self):
        self.data.embed_code = render_video(self.data.url)


plugin_registry.register(VideoPlugin)


# *************************************************************************
# ******************************* Big video plugin ************************
# *************************************************************************

class BigVideoPlugin(VideoPlugin):
    """
    Video dashboard plugin.
    """
    uid = 'big_video'
    name = _("Video")


plugin_registry.register(BigVideoPlugin)

# *************************************************************************
# ******************************* Huge video plugin ***********************
# *************************************************************************

class HugeVideoPlugin(VideoPlugin):
    """
    Video dashboard plugin.
    """
    uid = 'huge_video'
    name = _("Video")


plugin_registry.register(HugeVideoPlugin)


# *************************************************************************
# ******************************* Gigantic video plugin *******************
# *************************************************************************

class GiganticVideoPlugin(VideoPlugin):
    """
    Video dashboard plugin.
    """
    uid = 'gigantic_video'
    name = _("Video")


plugin_registry.register(GiganticVideoPlugin)

# *************************************************************************
# ****************** Registering the widgets for Video plugin *************
# *************************************************************************

# Registering the Android widgets for Video plugin.
plugin_widget_registry.register(VideoAndroidMainWidget)
plugin_widget_registry.register(BigVideoAndroidMainWidget)
plugin_widget_registry.register(HugeVideoAndroidMainWidget)
plugin_widget_registry.register(GiganticVideoAndroidMainWidget)

# Registering the Windows8widgets for Video plugin.
plugin_widget_registry.register(VideoWindows8MainWidget)
plugin_widget_registry.register(VideoWindows8SidebarWidget)



__all__ = ('DashboardWorkspaceForm',)

from django import forms

from dash.models import DashboardWorkspace, DashboardSettings

class DashboardWorkspaceForm(forms.ModelForm):
    """
    Dashboard workspace form.
    """
    class Meta:
        model = DashboardWorkspace
        exclude = ('position', 'layout_uid')

    def __init__(self, *args, **kwargs):
        super(DashboardWorkspaceForm, self).__init__(*args, **kwargs)
        self.fields['user'].widget = forms.widgets.HiddenInput()
        #self.fields['layout_uid'].widget = forms.widgets.HiddenInput()


class DashboardSettingsForm(forms.ModelForm):
    """
    Dashboard settings form.
    """
    class Meta:
        model = DashboardSettings

    def __init__(self, *args, **kwargs):
        super(DashboardSettingsForm, self).__init__(*args, **kwargs)
        self.fields['user'].widget = forms.widgets.HiddenInput()



__all__ = ('WeatherAndroidMainWidget', 'BigWeatherAndroidMainWidget')

from django.template.loader import render_to_string

from dash.base import BaseDashboardPluginWidget

# ***********************************************************************
# ****************** Android widgets for Memo plugin ********************
# ***********************************************************************

class WeatherAndroidMainWidget(BaseDashboardPluginWidget):
    """
    Weather plugin widget for Android layout (placeholder `main`).
    """
    layout_uid = 'android'
    placeholder_uid = 'main'
    plugin_uid = 'weather'
    cols = 2
    rows = 2

    #media_js = [
    #    'js/dash_plugin_weather.js',
    #]
    media_css = [
        'css/dash_plugin_weather.css',
    ]

    def render(self, request=None):
        context = {'plugin': self.plugin}
        return render_to_string('weather/render_main.html', context)


# ***************************************************************************
# ****************** Android widgets for Big weather plugin *****************
# ***************************************************************************

class BigWeatherAndroidMainWidget(WeatherAndroidMainWidget):
    """
    Big memo plugin widget for Android layout (placeholder `main`).
    """
    plugin_uid = 'big_weather'
    cols = 3
    rows = 3



__all__ = ('NewsPlugin', 'HugeNewsPlugin')

from django.utils.translation import ugettext_lazy as _

from slim.helpers import get_language_from_request

from dash.base import BaseDashboardPlugin, plugin_registry, plugin_widget_registry
from dash.contrib.plugins.news.models import NewsItem
from dash.contrib.plugins.news.forms import NewsForm
from dash.contrib.plugins.news.dash_widgets import NewsAndroidMainWidget, HugeNewsAndroidMainWidget

# ***************************************************************************
# ******************************* News plugin *******************************
# ***************************************************************************

class NewsPlugin(BaseDashboardPlugin):
    """
    News plugin.
    """
    uid = 'news'
    name = _("News")
    form = NewsForm
    group = _("News")

    def post_processor(self):
        """
        Getting news items for the current active language.
        """
        results_kwargs = {}

        language = get_language_from_request(self.request)
        if language is not None:
            results_kwargs.update({'language': language})

        self.data.news_items = NewsItem._default_manager.filter(**results_kwargs) \
                                       .order_by('-date_published')[:self.data.max_items]


plugin_registry.register(NewsPlugin)

# ***************************************************************************
# ******************************* Huge news plugin **************************
# ***************************************************************************

class HugeNewsPlugin(BaseDashboardPlugin):
    """
    News plugin.
    """
    uid = 'huge_news'
    name = _("News")
    form = NewsForm
    group = _("News")


plugin_registry.register(HugeNewsPlugin)

# *************************************************************************
# ****************** Registering the widgets ******************************
# *************************************************************************

# Registering the Android widgets for News plugin plugin.
plugin_widget_registry.register(NewsAndroidMainWidget)

# Registering the Android widgets for Huge news plugin plugin.
plugin_widget_registry.register(HugeNewsAndroidMainWidget)



__all__ = ('MemoPlugin', 'BigMemoPlugin', 'HugeMemoPlugin', 'TinyMCEMemoPlugin', \
           'BigTinyMCEMemoPlugin')

from django.utils.translation import ugettext_lazy as _

from dash.base import BaseDashboardPlugin, plugin_registry, plugin_widget_registry
from dash.contrib.plugins.memo.forms import MemoForm, TinyMCEMemoForm
from dash.contrib.plugins.memo.dash_widgets import MemoAndroidMainWidget, MemoAndroidShortcutWidget
from dash.contrib.plugins.memo.dash_widgets import BigMemoAndroidMainWidget, BigMemoWindows8MainWidget
from dash.contrib.plugins.memo.dash_widgets import HugeMemoAndroidMainWidget, TinyMCEMemoAndroidMainWidget
from dash.contrib.plugins.memo.dash_widgets import BigTinyMCEMemoAndroidMainWidget, MemoWindows8MainWidget
from dash.contrib.plugins.memo.dash_widgets import MemoWindows8SidebarWidget, BigMemoWindows8MainWidget
from dash.contrib.plugins.memo.dash_widgets import BigMemoWindows8SidebarWidget

# **************************************************************************
# ******************************* MemoPlugin *******************************
# **************************************************************************

class MemoPlugin(BaseDashboardPlugin):
    """
    Memo dashboard plugin.
    """
    uid = 'memo'
    name = _("Memo")
    group = _("Memo")
    form = MemoForm


plugin_registry.register(MemoPlugin)

# **************************************************************************
# ******************************* Big memo plugin **************************
# **************************************************************************

class BigMemoPlugin(MemoPlugin):
    """
    Exact copy of the memo plugin, just rendered bigger.
    """
    uid = 'big_memo'
    name = _("Memo")
    group = _("Memo")


plugin_registry.register(BigMemoPlugin)

# **************************************************************************
# ******************************* Huge memo plugin *************************
# **************************************************************************

class HugeMemoPlugin(MemoPlugin):
    """
    Exact copy of the memo plugin, just rendered bigger.
    """
    uid = 'huge_memo'
    name = _("Memo")
    group = _("Memo")


plugin_registry.register(HugeMemoPlugin)


# **************************************************************************
# ******************************* TinyMCE memo plugin **********************
# **************************************************************************

class TinyMCEMemoPlugin(BaseDashboardPlugin):
    """
    Memo dashboard plugin.
    """
    uid = 'tinymce_memo'
    name = _("TinyMCE memo")
    group = _("Memo")
    form = TinyMCEMemoForm
    help_text = _("""TinyMCE tags are available here.""")


plugin_registry.register(TinyMCEMemoPlugin)

# **************************************************************************
# ******************************* Big TinyMCE memo plugin ******************
# **************************************************************************

class BigTinyMCEMemoPlugin(TinyMCEMemoPlugin):
    """
    Exact copy of the memo plugin, just rendered bigger.
    """
    uid = 'big_tinymce_memo'
    name = _("TinyMCE memo")
    group = _("Memo")


plugin_registry.register(BigTinyMCEMemoPlugin)

# **************************************************************************
# ****************** Registering the widgets *******************************
# **************************************************************************

# Registering the Android widgets for Memo plugin.
plugin_widget_registry.register(MemoAndroidMainWidget)
plugin_widget_registry.register(MemoAndroidShortcutWidget)

# Registering the Android widgets for Big memo plugin.
plugin_widget_registry.register(BigMemoAndroidMainWidget)

# Registering the Windows8 widgets for Big memo plugin.
plugin_widget_registry.register(BigMemoWindows8MainWidget)

# Registering the Android widgets for Huge memo plugin.
plugin_widget_registry.register(HugeMemoAndroidMainWidget)

# Registering the Android widgets for TinyMCE memo plugin.
plugin_widget_registry.register(TinyMCEMemoAndroidMainWidget)

# Registering the Android widgets for Big TinyMCE memo plugin.
plugin_widget_registry.register(BigTinyMCEMemoAndroidMainWidget)

# Registering the Windows 8 widgets for Memo plugin.
plugin_widget_registry.register(MemoWindows8MainWidget)
plugin_widget_registry.register(MemoWindows8SidebarWidget)

# Registering the Windows 8 widgets for BigMemo plugin.
plugin_widget_registry.register(BigMemoWindows8MainWidget)
plugin_widget_registry.register(BigMemoWindows8SidebarWidget)



__all__ = ('slugify_workspace', 'lists_overlap')

from autoslug.settings import slugify

slugify_workspace = lambda s: slugify(s.lower()).lower()

def lists_overlap(sub, main):
    for i in sub:
        if i in main:
            return True
    return False



__all__ = ('ReadRSSFeedAndroidMainWidget', 'ReadRSSFeedWindows8MainWidget', 'BigReadRSSFeedAndroidMainWidget')

from django.core.context_processors import csrf
from django.template.loader import render_to_string

from dash.base import BaseDashboardPluginWidget

# ************************************************************************
# ****************** Android widgets for Read RSS feed plugin ************
# ************************************************************************
class ReadRSSFeedAndroidMainWidget(BaseDashboardPluginWidget):
    """
    Read RSS feed plugin widget for Android layout (placeholder `main`).
    """
    layout_uid = 'android'
    placeholder_uid = 'main'
    plugin_uid = 'read_rss_feed'
    cols = 2
    rows = 3

    media_js = [
        'js/dash_plugin_read_rss_feed.js',
    ]
    media_css = [
        'css/dash_plugin_read_rss_feed.css',
    ]

    def render(self, request=None):
        context = {'plugin': self.plugin, 'csrfmiddlewaretoken': csrf(request)}
        return render_to_string('rss_feed/render_main.html', context)

# ************************************************************************
# ****************** Android widgets for Big read RSS feed plugin ********
# ************************************************************************
class BigReadRSSFeedAndroidMainWidget(ReadRSSFeedAndroidMainWidget):
    """
    Big read RSS feed plugin widget for Android layout (placeholder `main`).
    """
    plugin_uid = 'big_read_rss_feed'
    cols = 3
    rows = 3


# ************************************************************************
# ****************** Windows8 widgets for Read RSS feed plugin ***********
# ************************************************************************
class ReadRSSFeedWindows8MainWidget(ReadRSSFeedAndroidMainWidget):
    """
    Read RSS feed plugin widget for Windows8 (placeholder `main`).
    """
    layout_uid = 'windows8'



__all__ = ('get_setting',)

from django.conf import settings

from dash.contrib.plugins.url import defaults

def get_setting(setting, override=None):
    """
    Get a setting from ``dash.contrib.plugins.url`` conf module, falling back to the default.

    If override is not None, it will be used instead of the setting.

    :param setting: String with setting name
    :param override: Value to use when no setting is available. Defaults to None.
    :return: Setting value.
    """
    if override is not None:
        return override
    if hasattr(settings, 'DASH_PLUGIN_URL_{0}'.format(setting)):
        return getattr(settings, 'DASH_PLUGIN_URL_{0}'.format(setting))
    else:
        return getattr(defaults, setting)



__all__ = ('URLPlugin',)

from django.utils.translation import ugettext_lazy as _

from dash.base import BaseDashboardPlugin, plugin_registry, plugin_widget_registry
from dash.contrib.plugins.url.forms import URLForm
from dash.contrib.plugins.url.dash_widgets import URLAndroidMainWidget, URLAndroidShortcutWidget
from dash.contrib.plugins.url.dash_widgets import URLWindows8MainWidget, URLWindows8SidebarWidget

# *************************************************************************
# ******************************* URL plugin ******************************
# *************************************************************************

class URLPlugin(BaseDashboardPlugin):
    """
    URL dashboard plugin.
    """
    uid = 'url'
    name = _("URL")
    group = _("URLs")
    form = URLForm

    @property
    def html_class(self):
        """
        If plugin has an image, we add a class `iconic` to it.
        """
        html_class = super(URLPlugin, self).html_class
        if self.data.image:
            html_class += ' iconic-url'
        return html_class

plugin_registry.register(URLPlugin)

# *************************************************************************
# ****************** Registering the widgets for URL plugin ***************
# *************************************************************************

# Registering the Android widgets for URL plugin.
plugin_widget_registry.register(URLAndroidMainWidget)
plugin_widget_registry.register(URLAndroidShortcutWidget)

# Registering the Windows8widgets for URL plugin.
plugin_widget_registry.register(URLWindows8MainWidget)
plugin_widget_registry.register(URLWindows8SidebarWidget)
